# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# NOTE: This file is auto generated by the elixir code generator program.
# Do not edit this file manually.

defmodule GoogleApi.CloudRun.V1alpha1.Model.SecretVolumeSource do
  @moduledoc """
  The secret's value will be presented as the content of a file whose name is defined in the item path. If no items are defined, the name of the file is the secret_name. The contents of the target Secret's Data field will be presented in a volume as files using the keys in the Data field as the file names.

  ## Attributes

  *   `defaultMode` (*type:* `integer()`, *default:* `nil`) - Integer representation of mode bits to use on created files by default. Must be a value between 01 and 0777 (octal). If 0 or not set, it will default to 0644. Directories within the path are not affected by this setting. Notes * Internally, a umask of 0222 will be applied to any non-zero value. * This is an integer representation of the mode bits. So, the octal integer value should look exactly as the chmod numeric notation with a leading zero. Some examples: for chmod 777 (a=rwx), set to 0777 (octal) or 511 (base-10). For chmod 640 (u=rw,g=r), set to 0640 (octal) or 416 (base-10). For chmod 755 (u=rwx,g=rx,o=rx), set to 0755 (octal) or 493 (base-10). * This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
  *   `items` (*type:* `list(GoogleApi.CloudRun.V1alpha1.Model.KeyToPath.t)`, *default:* `nil`) - (Optional) If unspecified, the volume will expose a file whose name is the secret_name. If specified, the key will be used as the version to fetch from Cloud Secret Manager and the path will be the name of the file exposed in the volume. When items are defined, they must specify a key and a path. If unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified that is not present in the Secret, the volume setup will error unless it is marked optional.
  *   `optional` (*type:* `boolean()`, *default:* `nil`) - (Optional) Specify whether the Secret or its keys must be defined.
  *   `secretName` (*type:* `String.t`, *default:* `nil`) - The name of the secret in Cloud Secret Manager. By default, the secret is assumed to be in the same project. If the secret is in another project, you must define an alias. An alias definition has the form: :projects//secrets/. If multiple alias definitions are needed, they must be separated by commas. The alias definitions must be set on the run.googleapis.com/secrets annotation. Name of the secret in the container's namespace to use.
  """

  use GoogleApi.Gax.ModelBase

  @type t :: %__MODULE__{
          :defaultMode => integer() | nil,
          :items => list(GoogleApi.CloudRun.V1alpha1.Model.KeyToPath.t()) | nil,
          :optional => boolean() | nil,
          :secretName => String.t() | nil
        }

  field(:defaultMode)
  field(:items, as: GoogleApi.CloudRun.V1alpha1.Model.KeyToPath, type: :list)
  field(:optional)
  field(:secretName)
end

defimpl Poison.Decoder, for: GoogleApi.CloudRun.V1alpha1.Model.SecretVolumeSource do
  def decode(value, options) do
    GoogleApi.CloudRun.V1alpha1.Model.SecretVolumeSource.decode(value, options)
  end
end

defimpl Poison.Encoder, for: GoogleApi.CloudRun.V1alpha1.Model.SecretVolumeSource do
  def encode(value, options) do
    GoogleApi.Gax.ModelBase.encode(value, options)
  end
end
